@@ -18,27 +18,37 @@
 
 /* Written by Scott G. Miller
    Credits:
-      Robert Klep <robert@ilse.nl>  -- Expansion function fix
-      Modifications for partial file reads by Brian Lindholm, 2004-2013.
-*/
+      Robert Klep <robert@ilse.nl> -- Expansion function fix
+      Modifications for portability and partial file reads by Brian Lindholm,
+      2004-2018.  */
 
 #include "../config.h"
-#include <sys/types.h>
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 #include "sha1.h"
-#include <stdalign.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <string.h>
-
-#if USE_UNLOCKED_IO
-# include "unlocked-io.h"
+#ifdef HAVE_STDALIGN_H
+# include <stdalign.h>
+#endif
+#ifdef HAVE_STDINT_H
+# include <stdint.h>
+#endif
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
 #endif
 
-#include <byteswap.h>
 #ifdef WORDS_BIGENDIAN
 # define SWAP(n) (n)
 #else
-# define SWAP(n) bswap_32 (n)
+# ifdef HAVE_BYTESWAP_H
+#  include <byteswap.h>
+#  define SWAP(n) bswap_32 (n)
+# else
+#  define SWAP(n) (((n) << 24) | (((n) & 0xff00) << 8) | (((n) >> 8) & 0xff00) | ((n) >> 24))
+# endif
 #endif
 
 #define BLOCKSIZE 32768
